@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Any
+
 
 # The BPMN-RPA Compare module is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ from typing import Any
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-def is_first_item_equal_to_second_item(first_item: Any, second_item: Any) -> bool:
+def is_first_item_equal_to_second_item(first_item: any, second_item: any) -> bool:
     """
     Compare two items and check if they are equal.
     :param first_item: The first item to compare.
@@ -24,7 +24,7 @@ def is_first_item_equal_to_second_item(first_item: Any, second_item: Any) -> boo
     return first_item == second_item
 
 
-def is_first_item_less_than_second_item(first_item: Any, second_item: Any) -> bool:
+def is_first_item_less_than_second_item(first_item: any, second_item: any) -> bool:
     """
     Check if first item is less than second item.
     :param first_item: The first item to compare.
@@ -38,7 +38,7 @@ def is_first_item_less_than_second_item(first_item: Any, second_item: Any) -> bo
     return first_item < second_item
 
 
-def is_first_item_greater_than_second_item(first_item: Any, second_item: Any) -> bool:
+def is_first_item_greater_than_second_item(first_item: any, second_item: any) -> bool:
     """
     Check if first item is greater than second item.
     :param first_item: The first item to compare.
@@ -52,7 +52,7 @@ def is_first_item_greater_than_second_item(first_item: Any, second_item: Any) ->
     return first_item > second_item
 
 
-def is_first_item_less_or_equal_than_second_item(first_item: Any, second_item: Any) -> bool:
+def is_first_item_less_or_equal_than_second_item(first_item: any, second_item: any) -> bool:
     """
     Check if first item is less or equal to second item.
     :param first_item: The first item to compare.
@@ -66,7 +66,7 @@ def is_first_item_less_or_equal_than_second_item(first_item: Any, second_item: A
     return first_item <= second_item
 
 
-def is_first_item_greater_or_equal_than_second_item(first_item: Any, second_item: Any) -> bool:
+def is_first_item_greater_or_equal_than_second_item(first_item: any, second_item: any) -> bool:
     """
     Check if first item is greater or equal to second item.
     :param first_item: The first item to compare.
@@ -80,7 +80,7 @@ def is_first_item_greater_or_equal_than_second_item(first_item: Any, second_item
     return first_item >= second_item
 
 
-def is_time_interval_less_or_equal(datetime1: Any, datetime2: Any, interval_in_seconds: int) -> bool:
+def is_time_interval_less_or_equal(datetime1: any, datetime2: any, interval_in_seconds: int) -> bool:
     """
     Check if the interval between 2 date-times is less or equal than the given amount of seconds.
     :param datetime1: The first datetime object.
@@ -95,7 +95,7 @@ def is_time_interval_less_or_equal(datetime1: Any, datetime2: Any, interval_in_s
     return (datetime2 - datetime1).total_seconds() <= int(interval_in_seconds)
 
 
-def is_time_number_of_seconds_ago(date_time: Any, interval_in_seconds: int) -> bool:
+def is_time_number_of_seconds_ago(date_time: any, interval_in_seconds: int) -> bool:
     """
     Check if the interval of a date-time is less or equal than the given amount of seconds compared to now.
     :param date_time: The datetime object.
@@ -107,7 +107,7 @@ def is_time_number_of_seconds_ago(date_time: Any, interval_in_seconds: int) -> b
     return (date_time - datetime.now()).total_seconds() <= int(interval_in_seconds)
 
 
-def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bool:
+def item1_contains_item2(item1: any, item2: any, exact_match: bool = True) -> bool:
     """
     Check if item 1 contains item2.
     :param exact_match:
@@ -136,7 +136,7 @@ def item1_contains_item2(item1: Any, item2: Any, exact_match: bool = True) -> bo
     return item1.__contains__(item2)
 
 
-def does_list_contain_item(list_object: list, item: Any) -> bool:
+def does_list_contain_item(list_object: list, item: any) -> bool:
     """
     Check if list contains an item.
     :param list_object: The list object.
@@ -146,7 +146,7 @@ def does_list_contain_item(list_object: list, item: Any) -> bool:
     return list_object.__contains__(item)
 
 
-def does_list_contain_any_items(list_object: Any) -> bool:
+def does_list_contain_any_items(list_object: any) -> bool:
     """
     Check if a list contains items.
     :param list_object: The list object to check.
@@ -155,13 +155,13 @@ def does_list_contain_any_items(list_object: Any) -> bool:
     if list_object is None:
         return False
     # region When working with email from ExchangeLib:
-    if str(inspected_object).lower().__contains__("queryset"):
-        count = int(str(inspected_object).split("=")[-1].replace(")", "").strip())
+    if str(list_object).lower().__contains__("queryset"):
+        count = int(str(list_object).split("=")[-1].replace(")", "").strip())
         if count == 0:
             return False
         else:
             return True
-    if str(inspected_object).lower().__contains__("message(mime_content"):
+    if str(list_object).lower().__contains__("message(mime_content"):
         return True
     # endregion
     if not isinstance(list_object, list):
@@ -176,7 +176,7 @@ def does_list_contain_any_items(list_object: Any) -> bool:
         return False
 
 
-def is_object_empty(inspected_object: Any) -> bool:
+def is_object_empty(inspected_object: any) -> bool:
     """
     Check if an item is empty.
     :return: Boolean True or False.
